'use strict';

var fs = require('fs');
var rollupPluginutils = require('rollup-pluginutils');

function css(options) {
  if ( options === void 0 ) options = {};

  var filter = rollupPluginutils.createFilter(options.include || ['**/*.css', '**/*.sass', '**/*.scss'], options.exclude || 'node_modules/**');
  var styles = {}
  var dest = options.output

  return {
    name: 'css',
    transform: function transform(code, id) {
      if (!filter(id)) {
        return
      }

      if (options.output === false) {
        return {
          code: 'export default ' + JSON.stringify(code),
          map: { mappings: '' }
        }
      }

      // Map of every stylesheet
      styles[id] = code

      return ''
    },
    ongenerate: function ongenerate (opts, rendered) {
      // No stylesheet needed
      if (options.output === false) {
        return
      }

      // Combine all stylesheets
      var css = ''
      for (var id in styles) {
        css += styles[id] || ''
      }

      // Emit styles through callback
      if (typeof options.output === 'function') {
        options.output(css, styles)
        return
      }

      if (typeof dest !== 'string') {
        // Don't create unwanted empty stylesheets
        if (!css.length) {
          return
        }

        // Guess destination filename
        dest = opts.dest || 'bundle.js'
        if (dest.endsWith('.js')) {
          dest = dest.slice(0, -3)
        }
        dest = dest + '.css'
      }

      // Emit styles to file
      fs.writeFile(dest, css, function (err) {
        if (err) {
          throw err
        }
        emitted(dest, css.length)
      })
    }
  };
}

module.exports = css;